@@ -1,5 +1,4 @@
 import argparse
-import getopt
 import glob
 import json
 import os
@@ -10,11 +9,12 @@ import subprocess
 import sys
 import time
 from pathlib import Path
+
 import requests
 from lxml import html
 from wand.image import Image
 
-version = '0.58.2'
+version = '0.58.4'
 
 user_agent = {"User-Agent": "git.io/wanda"}
 content_json = "application/json"
@@ -44,9 +44,9 @@ def parser():
         '-d',
         metavar='download',
         type=str,
-        default=Path.home(),
-        help='Save current wallpaper to home directory or given path',
+        default=None,
         required=False,
+        help='Save current wallpaper to home directory or given path',
     )
     parser_.add_argument(
         '-u',
@@ -60,8 +60,9 @@ def parser():
         '-v',
         metavar='version',
         help='Current version',
+        required=False,
         action="store_const",
-        const=None
+        const=version
     )
     if is_android():
         parser_.add_argument(
@@ -181,12 +182,15 @@ def size():
     except NameError:
         return "2560x1440"
 
+
 def is_landscape():
     return int(size().split("x")[0]) > int(size().split("x")[1])
 
+
 def is_portrait():
     return not is_landscape()
 
+
 def is_android():
     return os.environ.get('TERMUX_VERSION') is not None
 
@@ -219,7 +223,7 @@ def unsplash(search=None):
     return response if "source-404" not in response else no_results()
 
 
-def earthview(_):
+def earthview(_):  # NOSONAR
     tree = html.fromstring(requests.get("https://earthview.withgoogle.com").content)
     url = json.loads(tree.xpath("//body/@data-photo")[0])["photoUrl"]
     if is_landscape():
@@ -310,8 +314,7 @@ def reddit(search=None, subreddits=subreddit()):
     image_urls = ["reddit.com/gallery", "imgur.com/a", "imgur.com/gallery"]
     posts = list(filter(lambda p:
                         contains(p["data"]["url"], False, image_urls) and
-                        reddit_compare_image_size(p["data"]["title"])
-                        , posts))
+                        reddit_compare_image_size(p["data"]["title"]), posts))
     url = random.choice(posts)["data"]["url"]
     if "reddit.com/gallery" in url:
         return random.choice(reddit_gallery(url))
@@ -387,16 +390,35 @@ def fivehundredpx(search=None):
 
 
 def artstation_prints(search=None):
+    import cloudscraper
+
+    scraper = cloudscraper.create_scraper()
     orientation = "portrait" if is_portrait() else "landscape"
     search = search or ""
     api = f"https://www.artstation.com/api/v2/prints/public/printed_products.json?page=1&per_page=30" \
           f"&orientation={orientation}&sort=trending&visibility=profile&variant_filter=price_limits_per_type" \
           f"&q={search}"
-    response = requests.get(api, headers=user_agent).json()["data"]
+    response = scraper.get(api, headers=user_agent).json()["data"]
     return random.choice(response)["print_type_variants"][0]["image_urls"][0]["url"] if response else no_results()
 
 
+def artstation_artist(search=None):
+    import cloudscraper
+
+    scraper = cloudscraper.create_scraper()
+    response = scraper.get(f"https://www.artstation.com/users/{search}/hovercard.json", headers=user_agent)
+    if response.status_code != 200:
+        no_results()
+    projects = scraper.get(f"https://www.artstation.com/users/{search}/projects.json", headers=user_agent).json()
+    artwork = random.choice(projects["data"])["permalink"].split("/")[-1]
+    return scraper.get(f"https://www.artstation.com/projects/{artwork}.json", headers=user_agent).json()["assets"][0][
+        "image_url"]
+
+
 def artstation_any(search=None):
+    import cloudscraper
+
+    scraper = cloudscraper.create_scraper()
     search = "nature" if blank(search) else search
     body = {"query": search, "page": 1, "per_page": 50, "sorting": "relevance", "pro_first": "1", "filters": "[]",
             "additional_fields": []}
@@ -406,13 +428,13 @@ def artstation_any(search=None):
         "Host": "www.artstation.com",
         "Content-Type": content_json
     }
-    assets = requests.get(api, json=body, headers=headers).json()["data"]
+    assets = scraper.get(api, json=body, headers=headers).json()["data"]
     if isinstance(assets, str):
         no_results()
     hash_id = random.choice(assets)["hash_id"] if assets else no_results()
 
     api = f"https://www.artstation.com/projects/{hash_id}.json"
-    assets = requests.get(api, json=body, headers=headers).json()["assets"]
+    assets = scraper.get(api, json=body, headers=headers).json()["assets"]
     random.shuffle(assets)
     for asset in assets:
         h = asset["height"]
@@ -448,66 +470,67 @@ def waifuim(search=None):
 def usage():
     cyan = "\033[36m"
     pink = "\033[35m"
+    print("Use double quotes if your keyword or path has spaces")
     print("Supported sources:")
-    print(f"{cyan}4chan {pink}[search term]")
-    print(f"{cyan}500{cyan}px {pink}[search term]")
-    print(f"{cyan}arstation {pink}[search term]")
-    print(f"{cyan}arstation_{cyan}prints {pink}[search term for prints]")
-    print(f"{cyan}imgur {pink}[gallery id. example: qF259WO]")
-    print(f"{cyan}imsea {pink}[search term]")
+    print(f"{cyan}4chan {pink}[keyword]|[keyword@board]")
+    print(f"{cyan}500{cyan}px {pink}[keyword]")
+    print(f"{cyan}arstation {pink}[keyword]")
+    print(f"{cyan}arstation_{cyan}artist {pink}[id of artist. example: aenamiart]")
+    print(f"{cyan}arstation_{cyan}prints {pink}[keyword for prints]")
+    print(f"{cyan}imgur {pink}[gallery id. example: qF259WO]|[keyword]")
+    print(f"{cyan}imsea {pink}[keyword]")
     print(f"{cyan}earthview")
     print(f"{cyan}local {pink}[full path to folder]")
-    print(f"{cyan}reddit {pink}[search term]")
-    print(f"{cyan}unsplash {pink}[search term]")
-    print(f"{cyan}wallhaven {pink}[search term]")
+    print(f"{cyan}reddit {pink}[keyword]|[keyword@subreddit]")
+    print(f"{cyan}unsplash {pink}[keyword]")
+    print(f"{cyan}wallhaven {pink}[keyword(,keyword2,keyword3...&)]")
     print(f"{cyan}waifu.im {pink}[selected_tag-(excluded_tag)]")
     print("")
+    print("Wallhaven advanced usage:")
+    print("For full list of parameters, go to https://wallhaven.cc/help/api#search")
+    print("example: wanda -sw -tcar,lamborghini&colors=cc3333&categories=111&purity=100")
+    print("")
     print("\033[33mShort codes:")
     print(json.dumps(shortcodes(), indent=2).strip("{}").replace("\"", ""))
 
 
 def run():
+    args = parser().parse_args()
+    if '-u' in sys.argv:
+        usage()
+        exit(0)
+    if '-v' in sys.argv:
+        print(args.v)
+        exit(0)
+    if '-d' in sys.argv:
+        for src_file in Path(folder).glob('wanda_*.*'):
+            shutil.copy(src_file, args.d)
+            print(f"Copied to {src_file}")
+        exit(0)
+    source = args.s
+    term = args.t
     home = True
     lock = True
-    source = "unsplash"
-    term = None
-    home, lock, source, term = handle_args(home, lock, source, term)
+    if '-l' in sys.argv and args.l:
+        lock = True
+        home = False
+    if '-h' in sys.argv and args.h:
+        lock = False
+        home = True
 
-    handle_source(home, lock, source, term)
-
-
-def handle_args(home, lock, source, term):
-    args = parser().parse_args()
-    options, _ = getopt.getopt(
-        sys.argv[1:],
-        'us:t:d:ho',
-    )
-    for opt, _ in options:
-        if opt in "-u":
-            usage()
-            exit(0)
-        elif opt in "-d":
-            if os.path.exists(args.d):
-                shutil.move(folder, args.d.strip())
-            print(args.d)
-            exit(0)
-        if opt in "-s":
-            source = args.s.strip()
-        if opt in "-t":
-            term = args.t.strip()
-        if opt in "-l":
-            lock = True
-            home = False
-        if opt in "-h":
-            lock = False
-            home = True
-    return home, lock, source, term
+    try:
+        set_wp(eval(source_map(source))(term), home, lock)
+    except NameError:
+        print(f"Unknown source: '{source}'. Available sources:")
+        usage()
+    return 0
 
 
 def shortcodes():
     return {
         "4": "4chan",
         "5": "500px",
+        "aa": "artstation_artist",
         "ap": "artstation_prints",
         "a": "artstation",
         "e": "earthview",
@@ -525,13 +548,5 @@ def source_map(shortcode):
     return shortcodes().get(shortcode, shortcode)
 
 
-def handle_source(home, lock, source, term):
-    try:
-        set_wp(eval(source_map(source))(term), home, lock)
-    except NameError:
-        print(f"Unknown source: '{source}'. Available sources: ")
-        usage()
-
-
 if __name__ == "__main__":
     sys.exit(run())
